@@ -1,11 +1,11 @@
 /* -*-c-*- -------------- mixgtk_widgets.c :
  * Implementation of the functions declared in mixgtk_widgets.h
  * ------------------------------------------------------------------
- * Copyright (C) 2001, 2004, 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2004, 2006, 2007, 2014 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -124,7 +124,7 @@ mixgtk_widget_factory_init (void)
 GtkWidget *
 mixgtk_widget_factory_get (mixgtk_dialog_id_t dlg, mixgtk_widget_id_t widget)
 {
-  g_assert (widget < WIDGET_NO_);
+  g_assert ((long)widget < WIDGET_NO_);
 
   return mixgtk_widget_factory_get_child_by_name (dlg, names_[widget]);
 }
@@ -148,5 +148,3 @@ mixgtk_widget_factory_get_child_by_name (mixgtk_dialog_id_t dlg,
   if (!xml_[dlg]) init_xml_ (dlg);
   return glade_xml_get_widget (xml_[dlg], name);
 }
-
-
